# mongokit-ng

[![image](https://img.shields.io/pypi/v/mongokit-ng.svg)](https://pypi.python.org/pypi/mongokit-ng) [![image](https://img.shields.io/travis/Windfarer/mongokit-ng.svg)](https://travis-ci.org/Windfarer/mongokit-ng) [![Documentation
Status](https://readthedocs.org/projects/mongokit-ng/badge/?version=latest)](https://mongokit-ng.readthedocs.io/en/latest/?badge=latest) [![Updates](https://pyup.io/repos/github/Windfarer/mongokit-ng/shield.svg)](https://pyup.io/repos/github/Windfarer/mongokit-ng/) [![Python 3](https://pyup.io/repos/github/Windfarer/mongokit-ng/python-3-shield.svg)](https://pyup.io/repos/github/Windfarer/mongokit-ng/)


Thanks the origin author [namlook](https://github.com/namlook) to create mongokit [https://github.com/namlook/mongokit](https://github.com/namlook/mongokit)

Mongokit is a Python ODM of MongoDB.
This project ports mongokit to Python 3 and the latest pymongo (3.9+) version...


  - Free software: MIT license
  - Documentation: TODO.

## Install

```
pip install mongokit-ng
```

## Project Status
See [https://github.com/Windfarer/mongokit-ng/issues/1](https://github.com/Windfarer/mongokit-ng/issues/1)

## Credits

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.

Python 2 Mongokit codebase [https://github.com/namlook/mongokit](https://github.com/namlook/mongokit)